# mylibpythonpr

Módulo para exemplificar construção de projetos Python no curso PyTools

[![Build Status](https://travis-ci.com/gbianka/mylibpythonpro.svg?branch=main)](https://travis-ci.com/gbianka/mylibpythonpro)
[![Updates](https://pyup.io/repos/github/gbianka/mylibpythonpro/shield.svg)](https://pyup.io/repos/github/gbianka/mylibpythonpro/)
[![Python 3](https://pyup.io/repos/github/gbianka/mylibpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/gbianka/mylibpythonpro/)

Suportada versão 3 de Python

Para instalar (windows):
```console
python -m venv .venv
cd .venv/Scripts/activate
pip install -r requirements-dev.txt
```

Para instalar (linux):
```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```

Para conferir qualidade de código:
```console
(.venv) flake8
```

Tópicos abordados:
 1. Git
 2. Virtualenv
 3. Pip